@@ -18,7 +18,7 @@ shift
 
 printf >&2 "Opening dist archive %s ... " "${distfile}"
 tar -xovf "${distfile}"
-distdir="$(echo "${distfile}" | cut -d. -f1,2,3)"
+distdir="$(echo "${distfile}" | rev | cut -d. -f3- | rev)"
 cp -a packaging/installer/install-required-packages.sh "${distdir}/install-required-packages.sh"
 if [ ! -d "${distdir}" ]; then
   printf >&2 "ERROR: %s is not a directory" "${distdir}"
@@ -29,6 +29,7 @@ printf >&2 "Entering %s and starting docker run ..." "${distdir}"
 
 pushd "${distdir}" || exit 1
 docker run \
+  -e DO_NOT_TRACK=1 \
   -v "${PWD}:/netdata" \
   -w /netdata \
   "ubuntu:latest" \
