@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include <snappy.h>
-#include "remote_write.pb.h"
+#include "exporting/prometheus/remote_write/remote_write.pb.h"
 #include "remote_write.h"
 
 using namespace prometheus;
