@@ -1,6 +1,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "libnetdata/libnetdata.h"
+#include "libnetdata/required_dummies.h"
 
 #ifdef HAVE_SETNS
 #ifndef _GNU_SOURCE
@@ -16,40 +17,6 @@ char *environment[] = {
         NULL
 };
 
-
-// ----------------------------------------------------------------------------
-
-// callback required by fatal()
-void netdata_cleanup_and_exit(int ret) {
-    exit(ret);
-}
-
-void send_statistics( const char *action, const char *action_result, const char *action_data) {
-    (void) action;
-    (void) action_result;
-    (void) action_data;
-    return;
-}
-
-// callbacks required by popen()
-void signals_block(void) {};
-void signals_unblock(void) {};
-void signals_reset(void) {};
-
-// callback required by eval()
-int health_variable_lookup(const char *variable, uint32_t hash, struct rrdcalc *rc, calculated_number *result) {
-    (void)variable;
-    (void)hash;
-    (void)rc;
-    (void)result;
-    return 0;
-};
-
-// required by get_system_cpus()
-char *netdata_configured_host_prefix = "";
-
-// ----------------------------------------------------------------------------
-
 struct iface {
     const char *device;
     uint32_t hash;
@@ -453,7 +420,7 @@ void detect_veth_interfaces(pid_t pid) {
 
     if(!eligible_ifaces(host)) {
         errno = 0;
-        error("there are no double-linked host interfaces available.");
+        info("there are no double-linked host interfaces available.");
         goto cleanup;
     }
 
