@@ -6,38 +6,12 @@
  * Released under GPL v3+
  */
 
-#include "../../libnetdata/libnetdata.h"
+#include "libnetdata/libnetdata.h"
+#include "libnetdata/required_dummies.h"
+
+#include <cups/cups.h>
 #include <limits.h>
 
-// callback required by fatal()
-void netdata_cleanup_and_exit(int ret) {
-    exit(ret);
-}
-
-void send_statistics( const char *action, const char *action_result, const char *action_data) {
-    (void) action;
-    (void) action_result;
-    (void) action_data;
-    return;
-}
-
-// callbacks required by popen()
-void signals_block(void) {};
-void signals_unblock(void) {};
-void signals_reset(void) {};
-
-// callback required by eval()
-int health_variable_lookup(const char *variable, uint32_t hash, struct rrdcalc *rc, calculated_number *result) {
-    (void)variable;
-    (void)hash;
-    (void)rc;
-    (void)result;
-    return 0;
-};
-
-// required by get_system_cpus()
-char *netdata_configured_host_prefix = "";
-
 // Variables
 
 static int debug = 0;
@@ -45,14 +19,10 @@ static int debug = 0;
 static int netdata_update_every = 1;
 static int netdata_priority = 100004;
 
-
-#ifdef HAVE_CUPS
-#include <cups/cups.h>
-
 http_t *http; // connection to the cups daemon
 
 /*
- * Used to aggregate job metrics for a destination (and all destianations).
+ * Used to aggregate job metrics for a destination (and all destinations).
  */
 struct job_metrics {
     int is_collected; // flag if this was collected in the current cycle
@@ -468,12 +438,3 @@ int main(int argc, char **argv) {
     httpClose(http);
     info("CUPS process exiting");
 }
-
-#else // !HAVE_CUPS
-
-int main(int argc, char **argv)
-{
-    fatal("cups.plugin is not compiled.");
-}
-
-#endif // !HAVE_CUPS
