@@ -185,7 +185,7 @@ static struct disk *get_disk(const char *name) {
 
 int do_kern_devstat(int update_every, usec_t dt) {
 
-#define DELAULT_EXLUDED_DISKS ""
+#define DEFAULT_EXCLUDED_DISKS ""
 #define CONFIG_SECTION_KERN_DEVSTAT "plugin:freebsd:kern.devstat"
 #define BINTIME_SCALE 5.42101086242752217003726400434970855712890625e-17 // this is 1000/2^64
 
@@ -222,7 +222,7 @@ int do_kern_devstat(int update_every, usec_t dt) {
                                                 CONFIG_BOOLEAN_AUTO);
 
         excluded_disks = simple_pattern_create(
-                config_get(CONFIG_SECTION_KERN_DEVSTAT, "disable by default disks matching", DELAULT_EXLUDED_DISKS)
+                config_get(CONFIG_SECTION_KERN_DEVSTAT, "disable by default disks matching", DEFAULT_EXCLUDED_DISKS)
                 , NULL
                 , SIMPLE_PATTERN_EXACT
         );
