@@ -213,8 +213,8 @@ int do_kstat_zfs_misc_arcstats(int update_every, usec_t dt) {
     // missing mib: GETSYSCTL_SIMPLE("kstat.zfs.misc.arcstats.arc_need_free", mibs.arc_need_free, arcstats.arc_need_free);
     // missing mib: GETSYSCTL_SIMPLE("kstat.zfs.misc.arcstats.arc_sys_free", mibs.arc_sys_free, arcstats.arc_sys_free);
 
-    generate_charts_arcstats("freebsd", "zfs", show_zero_charts, update_every);
-    generate_charts_arc_summary("freebsd", "zfs", show_zero_charts, update_every);
+    generate_charts_arcstats("freebsd.plugin", "zfs", show_zero_charts, update_every);
+    generate_charts_arc_summary("freebsd.plugin", "zfs", show_zero_charts, update_every);
 
     return 0;
 }
@@ -252,7 +252,7 @@ int do_kstat_zfs_misc_zio_trim(int update_every, usec_t dt) {
                     NULL,
                     "Successfully TRIMmed bytes",
                     "bytes",
-                    "freebsd",
+                    "freebsd.plugin",
                     "zfs",
                     2320,
                     update_every,
@@ -280,7 +280,7 @@ int do_kstat_zfs_misc_zio_trim(int update_every, usec_t dt) {
                     NULL,
                     "TRIM requests",
                     "requests",
-                    "freebsd",
+                    "freebsd.plugin",
                     "zfs",
                     2321,
                     update_every,
@@ -301,4 +301,4 @@ int do_kstat_zfs_misc_zio_trim(int update_every, usec_t dt) {
      }
 
     return 0;
-}
\ No newline at end of file
+}
