@@ -15,7 +15,8 @@
  *  UCRL-CODE-222073
  */
 
-#include "../../libnetdata/libnetdata.h"
+#include "libnetdata/libnetdata.h"
+#include "libnetdata/required_dummies.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -26,8 +27,6 @@
 #include <unistd.h>
 #include <sys/time.h>
 
-#ifdef HAVE_FREEIPMI
-
 #define IPMI_PARSE_DEVICE_LAN_STR       "lan"
 #define IPMI_PARSE_DEVICE_LAN_2_0_STR   "lan_2_0"
 #define IPMI_PARSE_DEVICE_LAN_2_0_STR2  "lan20"
@@ -42,39 +41,6 @@
 #define IPMI_PARSE_DEVICE_SUNBMC_STR2   "bmc"
 #define IPMI_PARSE_DEVICE_INTELDCMI_STR "inteldcmi"
 
-// ----------------------------------------------------------------------------
-
-// callback required by fatal()
-void netdata_cleanup_and_exit(int ret) {
-    exit(ret);
-}
-
-void send_statistics( const char *action, const char *action_result, const char *action_data) {
-    (void)action;
-    (void)action_result;
-    (void)action_data;
-    return;
-}
-
-// callbacks required by popen()
-void signals_block(void) {};
-void signals_unblock(void) {};
-void signals_reset(void) {};
-
-// callback required by eval()
-int health_variable_lookup(const char *variable, uint32_t hash, struct rrdcalc *rc, calculated_number *result) {
-    (void)variable;
-    (void)hash;
-    (void)rc;
-    (void)result;
-    return 0;
-};
-
-// required by get_system_cpus()
-char *netdata_configured_host_prefix = "";
-
-// ----------------------------------------------------------------------------
-
 #include <ipmi_monitoring.h>
 #include <ipmi_monitoring_bitmasks.h>
 
@@ -1621,6 +1587,14 @@ int parse_outofband_driver_type (const char *str)
     return (-1);
 }
 
+int host_is_local(const char *host)
+{
+    if (host && (!strcmp(host, "localhost") || !strcmp(host, "127.0.0.1") || !strcmp(host, "::1")))
+        return (1);
+
+    return (0);
+}
+
 int main (int argc, char **argv) {
 
     // ------------------------------------------------------------------------
@@ -1691,6 +1665,8 @@ int main (int argc, char **argv) {
                     "  password PASS           connect to remote IPMI host\n"
                     "                          default: local IPMI processor\n"
                     "\n"
+                    "  noauthcodecheck         don't check the authentication codes returned\n"
+                    "\n"
                     " driver-type IPMIDRIVER\n"
                     "                          Specify the driver type to use instead of doing an auto selection. \n"
                     "                          The currently available outofband drivers are LAN and  LAN_2_0,\n"
@@ -1765,6 +1741,23 @@ int main (int argc, char **argv) {
                 if(debug) fprintf(stderr, "freeipmi.plugin: inband driver type set to '%d'\n", driver_type);
             }
             continue;
+        } else if (i < argc && strcmp("noauthcodecheck", argv[i]) == 0) {
+            if (!hostname || host_is_local(hostname)) {
+                if (debug)
+                    fprintf(
+                        stderr,
+                        "freeipmi.plugin: noauthcodecheck workaround flag is ignored for inband configuration\n");
+            } else if (protocol_version < 0 || protocol_version == IPMI_MONITORING_PROTOCOL_VERSION_1_5) {
+                workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_PROTOCOL_VERSION_1_5_NO_AUTH_CODE_CHECK;
+                if (debug)
+                    fprintf(stderr, "freeipmi.plugin: noauthcodecheck workaround flag enabled\n");
+            } else {
+                if (debug)
+                    fprintf(
+                        stderr,
+                        "freeipmi.plugin: noauthcodecheck workaround flag is ignored for protocol version 2.0\n");
+            }
+            continue;
         }
         else if(i < argc && strcmp("sdr-cache-dir", argv[i]) == 0) {
             sdr_cache_directory = argv[++i];
@@ -1861,11 +1854,3 @@ int main (int argc, char **argv) {
         if(now_monotonic_sec() - started_t > 14400) exit(0);
     }
 }
-
-#else // !HAVE_FREEIPMI
-
-int main(int argc, char **argv) {
-    fatal("freeipmi.plugin is not compiled.");
-}
-
-#endif // !HAVE_FREEIPMI
