@@ -1,6 +1,11 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-#include "../../libnetdata/libnetdata.h"
+#include "libnetdata/libnetdata.h"
+#include "libnetdata/required_dummies.h"
+
+#include <linux/netfilter/nfnetlink_conntrack.h>
+#include <libmnl/libmnl.h>
+#include <libnetfilter_acct/libnetfilter_acct.h>
 
 #define PLUGIN_NFACCT_NAME "nfacct.plugin"
 
@@ -13,62 +18,19 @@
 #define NETDATA_CHART_PRIO_NETFILTER_PACKETS          8906
 #define NETDATA_CHART_PRIO_NETFILTER_BYTES            8907
 
-#ifdef HAVE_LIBMNL
-#include <libmnl/libmnl.h>
-
 static inline size_t mnl_buffer_size() {
     long s = MNL_SOCKET_BUFFER_SIZE;
     if(s <= 0) return 8192;
     return (size_t)s;
 }
 
-// callback required by fatal()
-void netdata_cleanup_and_exit(int ret) {
-    exit(ret);
-}
-
-void send_statistics( const char *action, const char *action_result, const char *action_data) {
-    (void) action;
-    (void) action_result;
-    (void) action_data;
-    return;
-}
-
-// callbacks required by popen()
-void signals_block(void) {};
-void signals_unblock(void) {};
-void signals_reset(void) {};
-
-// callback required by eval()
-int health_variable_lookup(const char *variable, uint32_t hash, struct rrdcalc *rc, calculated_number *result) {
-    (void)variable;
-    (void)hash;
-    (void)rc;
-    (void)result;
-    return 0;
-};
-
-// required by get_system_cpus()
-char *netdata_configured_host_prefix = "";
-
-// Variables
-
+// variables
 static int debug = 0;
-
 static int netdata_update_every = 1;
 
-// ----------------------------------------------------------------------------
-// DO_NFSTAT - collect netfilter connection tracker statistics via netlink
-// example: https://github.com/formorer/pkg-conntrack-tools/blob/master/src/conntrack.c
-
-#ifdef HAVE_LINUX_NETFILTER_NFNETLINK_CONNTRACK_H
-#define DO_NFSTAT 1
-
 #define RRD_TYPE_NET_STAT_NETFILTER "netfilter"
 #define RRD_TYPE_NET_STAT_CONNTRACK "netlink"
 
-#include <linux/netfilter/nfnetlink_conntrack.h>
-
 static struct {
     int update_every;
     char *buf;
@@ -530,16 +492,6 @@ static void nfstat_send_metrics() {
     printf("END\n");
 }
 
-#endif // HAVE_LINUX_NETFILTER_NFNETLINK_CONNTRACK_H
-
-
-// ----------------------------------------------------------------------------
-// DO_NFACCT - collect netfilter accounting statistics via netlink
-
-#ifdef HAVE_LIBNETFILTER_ACCT
-#define DO_NFACCT 1
-
-#include <libnetfilter_acct/libnetfilter_acct.h>
 
 struct nfacct_data {
     char *name;
@@ -712,7 +664,11 @@ static void nfacct_send_metrics() {
         if(likely(d->updated)) {
             if(unlikely(!d->packets_dimension_added)) {
                 d->packets_dimension_added = 1;
-                printf("CHART netfilter.nfacct_packets '' 'Netfilter Accounting Packets' 'packets/s'\n");
+                printf(
+                    "CHART netfilter.nfacct_packets '' 'Netfilter Accounting Packets' 'packets/s' 'nfacct' '' stacked %d %d %s\n",
+                    NETDATA_CHART_PRIO_NETFILTER_PACKETS,
+                    nfacct_root.update_every,
+                    PLUGIN_NFACCT_NAME);
                 printf("DIMENSION %s '' incremental 1 %d\n", d->name, nfacct_root.update_every);
             }
         }
@@ -743,7 +699,11 @@ static void nfacct_send_metrics() {
         if(likely(d->updated)) {
             if(unlikely(!d->bytes_dimension_added)) {
                 d->bytes_dimension_added = 1;
-                printf("CHART netfilter.nfacct_bytes '' 'Netfilter Accounting Bandwidth' 'kilobytes/s'\n");
+                printf(
+                    "CHART netfilter.nfacct_bytes '' 'Netfilter Accounting Bandwidth' 'kilobytes/s' 'nfacct' '' stacked %d %d %s\n",
+                    NETDATA_CHART_PRIO_NETFILTER_BYTES,
+                    nfacct_root.update_every,
+                    PLUGIN_NFACCT_NAME);
                 printf("DIMENSION %s '' incremental 1 %d\n", d->name, 1000 * nfacct_root.update_every);
             }
         }
@@ -760,8 +720,6 @@ static void nfacct_send_metrics() {
     printf("END\n");
 }
 
-#endif // HAVE_LIBNETFILTER_ACCT
-
 static void nfacct_signal_handler(int signo)
 {
     exit((signo == SIGPIPE)?1:0);
@@ -866,15 +824,13 @@ int main(int argc, char **argv) {
     else if(freq)
         error("update frequency %d seconds is too small for NFACCT. Using %d.", freq, netdata_update_every);
 
-#ifdef DO_NFACCT
-    if(debug) fprintf(stderr, "nfacct.plugin: calling nfacct_init()\n");
+    if (debug)
+        fprintf(stderr, "nfacct.plugin: calling nfacct_init()\n");
     int nfacct = !nfacct_init(netdata_update_every);
-#endif
 
-#ifdef DO_NFSTAT
-    if(debug) fprintf(stderr, "nfacct.plugin: calling nfstat_init()\n");
+    if (debug)
+        fprintf(stderr, "nfacct.plugin: calling nfstat_init()\n");
     int nfstat = !nfstat_init(netdata_update_every);
-#endif
 
     // ------------------------------------------------------------------------
     // the main loop
@@ -899,7 +855,6 @@ int main(int argc, char **argv) {
                     , dt
             );
 
-#ifdef DO_NFACCT
         if(likely(nfacct)) {
             if(debug) fprintf(stderr, "nfacct.plugin: calling nfacct_collect()\n");
             nfacct = !nfacct_collect();
@@ -909,9 +864,7 @@ int main(int argc, char **argv) {
                 nfacct_send_metrics();
             }
         }
-#endif
 
-#ifdef DO_NFSTAT
         if(likely(nfstat)) {
             if(debug) fprintf(stderr, "nfacct.plugin: calling nfstat_collect()\n");
             nfstat = !nfstat_collect();
@@ -921,7 +874,6 @@ int main(int argc, char **argv) {
                 nfstat_send_metrics();
             }
         }
-#endif
 
         fflush(stdout);
 
@@ -931,14 +883,3 @@ int main(int argc, char **argv) {
 
     info("NFACCT process exiting");
 }
-
-#else // !HAVE_LIBMNL
-
-int main(int argc, char **argv) {
-    (void)argc;
-    (void)argv;
-
-    fatal("nfacct.plugin is not compiled.");
-}
-
-#endif // !HAVE_LIBMNL
