@@ -3,27 +3,11 @@
 #ifndef NETDATA_PLUGIN_PROC_H
 #define NETDATA_PLUGIN_PROC_H 1
 
-#include "../../daemon/common.h"
-
-#if (TARGET_OS == OS_LINUX)
-
-#define NETDATA_PLUGIN_HOOK_LINUX_PROC \
-    { \
-        .name = "PLUGIN[proc]", \
-        .config_section = CONFIG_SECTION_PLUGINS, \
-        .config_name = "proc", \
-        .enabled = 1, \
-        .thread = NULL, \
-        .init_routine = NULL, \
-        .start_routine = proc_main \
-    },
-
+#include "daemon/common.h"
 
 #define PLUGIN_PROC_CONFIG_NAME "proc"
 #define PLUGIN_PROC_NAME PLUGIN_PROC_CONFIG_NAME ".plugin"
 
-extern void *proc_main(void *ptr);
-
 extern int do_proc_net_dev(int update_every, usec_t dt);
 extern int do_proc_net_wireless(int update_every, usec_t dt);
 extern int do_proc_diskstats(int update_every, usec_t dt);
@@ -51,6 +35,7 @@ extern int do_proc_uptime(int update_every, usec_t dt);
 extern int do_proc_sys_devices_system_edac_mc(int update_every, usec_t dt);
 extern int do_proc_sys_devices_system_node(int update_every, usec_t dt);
 extern int do_proc_spl_kstat_zfs_arcstats(int update_every, usec_t dt);
+extern int do_proc_spl_kstat_zfs_pool_state(int update_every, usec_t dt);
 extern int do_sys_fs_btrfs(int update_every, usec_t dt);
 extern int do_proc_net_sockstat(int update_every, usec_t dt);
 extern int do_proc_net_sockstat6(int update_every, usec_t dt);
@@ -73,11 +58,4 @@ extern void netdev_rename_device_del(const char *host_device);
 #include "proc_pressure.h"
 #include "zfs_common.h"
 
-#else // (TARGET_OS == OS_LINUX)
-
-#define NETDATA_PLUGIN_HOOK_LINUX_PROC
-
-#endif // (TARGET_OS == OS_LINUX)
-
-
 #endif /* NETDATA_PLUGIN_PROC_H */
