@@ -1,6 +1,10 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-#include "../../libnetdata/libnetdata.h"
+#include "libnetdata/libnetdata.h"
+#include "libnetdata/required_dummies.h"
+
+#include <xenstat.h>
+#include <libxl.h>
 
 #define PLUGIN_XENSTAT_NAME "xenstat.plugin"
 
@@ -32,45 +36,10 @@
 #define CHART_IS_OBSOLETE     1
 #define CHART_IS_NOT_OBSOLETE 0
 
-// callback required by fatal()
-void netdata_cleanup_and_exit(int ret) {
-    exit(ret);
-}
-
-void send_statistics( const char *action, const char *action_result, const char *action_data) {
-    (void) action;
-    (void) action_result;
-    (void) action_data;
-    return;
-}
-
-// callbacks required by popen()
-void signals_block(void) {};
-void signals_unblock(void) {};
-void signals_reset(void) {};
-
-// callback required by eval()
-int health_variable_lookup(const char *variable, uint32_t hash, struct rrdcalc *rc, calculated_number *result) {
-    (void)variable;
-    (void)hash;
-    (void)rc;
-    (void)result;
-    return 0;
-};
-
-// required by get_system_cpus()
-char *netdata_configured_host_prefix = "";
-
 // Variables
-
 static int debug = 0;
-
 static int netdata_update_every = 1;
 
-#ifdef HAVE_LIBXENSTAT
-#include <xenstat.h>
-#include <libxl.h>
-
 struct vcpu_metrics {
     unsigned int id;
 
@@ -1093,14 +1062,3 @@ int main(int argc, char **argv) {
     xenstat_uninit(xhandle);
     info("XENSTAT process exiting");
 }
-
-#else // !HAVE_LIBXENSTAT
-
-int main(int argc, char **argv) {
-    (void)argc;
-    (void)argv;
-
-    fatal("xenstat.plugin is not compiled.");
-}
-
-#endif // !HAVE_LIBXENSTAT
