@@ -1,7 +1,6 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "common.h"
-#include "../database/engine/rrdenginelib.h"
 
 static uv_thread_t thread;
 static uv_loop_t* loop;
@@ -46,6 +45,7 @@ static cmd_status_t cmd_reload_labels_execute(char *args, char **message);
 static cmd_status_t cmd_read_config_execute(char *args, char **message);
 static cmd_status_t cmd_write_config_execute(char *args, char **message);
 static cmd_status_t cmd_ping_execute(char *args, char **message);
+static cmd_status_t cmd_aclk_state(char *args, char **message);
 
 static command_info_t command_info_array[] = {
         {"help", cmd_help_execute, CMD_TYPE_HIGH_PRIORITY},                  // show help menu
@@ -58,7 +58,8 @@ static command_info_t command_info_array[] = {
         {"reload-labels", cmd_reload_labels_execute, CMD_TYPE_ORTHOGONAL},   // reload the labels
         {"read-config", cmd_read_config_execute, CMD_TYPE_CONCURRENT},
         {"write-config", cmd_write_config_execute, CMD_TYPE_ORTHOGONAL},
-        {"ping", cmd_ping_execute, CMD_TYPE_ORTHOGONAL}
+        {"ping", cmd_ping_execute, CMD_TYPE_ORTHOGONAL},
+        {"aclk-state", cmd_aclk_state, CMD_TYPE_ORTHOGONAL}
 };
 
 /* Mutexes for commands of type CMD_TYPE_ORTHOGONAL */
@@ -121,7 +122,9 @@ static cmd_status_t cmd_help_execute(char *args, char **message)
              "reload-claiming-state\n"
              "    Reload agent claiming state from disk.\n"
              "ping\n"
-             "    Return with 'pong' if agent is alive.\n",
+             "    Return with 'pong' if agent is alive.\n"
+             "aclk-state [json]\n"
+             "    Returns current state of ACLK and Cloud connection. (optionally in json)\n",
              MAX_COMMAND_LENGTH - 1);
     return CMD_STATUS_SUCCESS;
 }
@@ -310,6 +313,17 @@ static cmd_status_t cmd_ping_execute(char *args, char **message)
     return CMD_STATUS_SUCCESS;
 }
 
+static cmd_status_t cmd_aclk_state(char *args, char **message)
+{
+    info("COMMAND: Reopening aclk/cloud state.");
+    if (strstr(args, "json"))
+        *message = aclk_state_json();
+    else
+        *message = aclk_state();
+
+    return CMD_STATUS_SUCCESS;
+}
+
 static void cmd_lock_exclusive(unsigned index)
 {
     (void)index;
@@ -625,7 +639,7 @@ static void command_thread(void *arg)
     command_thread_error = 0;
     command_thread_shutdown = 0;
     /* wake up initialization thread */
-    complete(&completion);
+    completion_mark_complete(&completion);
 
     while (command_thread_shutdown == 0) {
         uv_run(loop, UV_RUN_DEFAULT);
@@ -654,7 +668,7 @@ error_after_loop_init:
     freez(loop);
 
     /* wake up initialization thread */
-    complete(&completion);
+    completion_mark_complete(&completion);
 }
 
 static void sanity_check(void)
@@ -678,15 +692,15 @@ void commands_init(void)
     }
     fatal_assert(0 == uv_rwlock_init(&exclusive_rwlock));
 
-    init_completion(&completion);
+    completion_init(&completion);
     error = uv_thread_create(&thread, command_thread, NULL);
     if (error) {
         error("uv_thread_create(): %s", uv_strerror(error));
         goto after_error;
     }
     /* wait for worker thread to initialize */
-    wait_for_completion(&completion);
-    destroy_completion(&completion);
+    completion_wait_for(&completion);
+    completion_destroy(&completion);
     uv_thread_set_name_np(thread, "DAEMON_COMMAND");
 
     if (command_thread_error) {
