@@ -181,8 +181,10 @@ static void oom_score_adj(void) {
         return;
     }
 
-    if(old_score != 0)
+    if (old_score != 0) {
         wanted_score = old_score;
+        analytics_report_oom_score(old_score);
+    }
 
     // check the environment
     char *s = getenv("OOMScoreAdjust");
@@ -234,6 +236,7 @@ static void oom_score_adj(void) {
                 info("Adjusted my Out-Of-Memory (OOM) score from %d to %d.", (int)old_score, (int)final_score);
             else
                 error("Adjusted my Out-Of-Memory (OOM) score from %d to %d, but it has been set to %d.", (int)old_score, (int)wanted_score, (int)final_score);
+            analytics_report_oom_score(final_score);
         }
         else
             error("Failed to adjust my Out-Of-Memory (OOM) score to %d. Running with %d. (systemd systems may change it via netdata.service)", (int)wanted_score, (int)old_score);
