@@ -11,10 +11,15 @@
 struct rrdcalctemplate {
     char *name;
     uint32_t hash_name;
+    uuid_t config_hash_id;
 
     char *exec;
     char *recipient;
 
+    char *classification;
+    char *component;
+    char *type;
+
     char *context;
     uint32_t hash_context;
 
@@ -27,6 +32,9 @@ struct rrdcalctemplate {
     char *module_match;
     SIMPLE_PATTERN *module_pattern;
 
+    char *charts_match;
+    SIMPLE_PATTERN *charts_pattern;
+
     char *source;                   // the source of this alarm
     char *units;                    // the units of the alarm
     char *info;                     // a short description of the alarm
