@@ -66,6 +66,8 @@ struct instance_config {
 
     const char *name;
     const char *destination;
+    const char *username;
+    const char *password;
     const char *prefix;
     const char *hostname;
 
@@ -77,6 +79,8 @@ struct instance_config {
     SIMPLE_PATTERN *charts_pattern;
     SIMPLE_PATTERN *hosts_pattern;
 
+    int initialized;
+
     void *connector_specific_config;
 };
 
@@ -96,9 +100,15 @@ struct simple_connector_buffer {
     struct simple_connector_buffer *next;
 };
 
+#define CONNECTED_TO_MAX 1024
+
 struct simple_connector_data {
     void *connector_specific_data;
 
+    char connected_to[CONNECTED_TO_MAX];
+    
+    char *auth_string;
+
     size_t total_buffered_metrics;
 
     BUFFER *header;
