@@ -16,18 +16,20 @@
  */
 inline int can_send_rrdset(struct instance *instance, RRDSET *st)
 {
+#ifdef NETDATA_INTERNAL_CHECKS
     RRDHOST *host = st->rrdhost;
+#endif
 
-    if (unlikely(rrdset_flag_check(st, RRDSET_FLAG_BACKEND_IGNORE)))
+    if (unlikely(rrdset_flag_check(st, RRDSET_FLAG_EXPORTING_IGNORE)))
         return 0;
 
-    if (unlikely(!rrdset_flag_check(st, RRDSET_FLAG_BACKEND_SEND))) {
+    if (unlikely(!rrdset_flag_check(st, RRDSET_FLAG_EXPORTING_SEND))) {
         // we have not checked this chart
         if (simple_pattern_matches(instance->config.charts_pattern, st->id) ||
             simple_pattern_matches(instance->config.charts_pattern, st->name))
-            rrdset_flag_set(st, RRDSET_FLAG_BACKEND_SEND);
+            rrdset_flag_set(st, RRDSET_FLAG_EXPORTING_SEND);
         else {
-            rrdset_flag_set(st, RRDSET_FLAG_BACKEND_IGNORE);
+            rrdset_flag_set(st, RRDSET_FLAG_EXPORTING_IGNORE);
             debug(
                 D_BACKEND,
                 "EXPORTING: not sending chart '%s' of host '%s', because it is disabled for exporting.",
@@ -37,7 +39,7 @@ inline int can_send_rrdset(struct instance *instance, RRDSET *st)
         }
     }
 
-    if (unlikely(!rrdset_is_available_for_backends(st))) {
+    if (unlikely(!rrdset_is_available_for_exporting_and_alarms(st))) {
         debug(
             D_BACKEND,
             "EXPORTING: not sending chart '%s' of host '%s', because it is not available for exporting.",
@@ -136,7 +138,7 @@ static inline time_t prometheus_server_last_access(const char *server, RRDHOST *
  * Copy and sanitize name.
  *
  * @param d a destination string.
- * @param s a source sting.
+ * @param s a source string.
  * @param usable the number of characters to copy.
  * @return Returns the length of the copied string.
  */
@@ -161,7 +163,7 @@ inline size_t prometheus_name_copy(char *d, const char *s, size_t usable)
  * Copy and sanitize label.
  *
  * @param d a destination string.
- * @param s a source sting.
+ * @param s a source string.
  * @param usable the number of characters to copy.
  * @return Returns the length of the copied string.
  */
@@ -190,7 +192,7 @@ inline size_t prometheus_label_copy(char *d, const char *s, size_t usable)
  * Copy and sanitize units.
  *
  * @param d a destination string.
- * @param s a source sting.
+ * @param s a source string.
  * @param usable the number of characters to copy.
  * @param showoldunits set this flag to 1 to show old (before v1.12) units.
  * @return Returns the destination string.
@@ -660,7 +662,8 @@ static void rrd_stats_api_v1_charts_allmetrics_prometheus(
                             rd->algorithm == RRD_ALGORITHM_PCENT_OVER_DIFF_TOTAL) {
                             p.type = "counter";
                             p.relation = "delta gives";
-                            p.suffix = "_total";
+                            if (!prometheus_collector)
+                                p.suffix = "_total";
                         }
 
                         if (homogeneous) {
@@ -793,6 +796,9 @@ static inline time_t prometheus_preparation(
     time_t now,
     PROMETHEUS_OUTPUT_OPTIONS output_options)
 {
+#ifndef UNIT_TESTING
+    analytics_log_prometheus();
+#endif
     if (!server || !*server)
         server = "default";
 
@@ -854,7 +860,7 @@ void rrd_stats_api_v1_charts_allmetrics_prometheus_single_host(
     EXPORTING_OPTIONS exporting_options,
     PROMETHEUS_OUTPUT_OPTIONS output_options)
 {
-    if (unlikely(!prometheus_exporter_instance))
+    if (unlikely(!prometheus_exporter_instance || !prometheus_exporter_instance->config.initialized))
         return;
 
     prometheus_exporter_instance->before = now_realtime_sec();
@@ -891,7 +897,7 @@ void rrd_stats_api_v1_charts_allmetrics_prometheus_all_hosts(
     EXPORTING_OPTIONS exporting_options,
     PROMETHEUS_OUTPUT_OPTIONS output_options)
 {
-    if (unlikely(!prometheus_exporter_instance))
+    if (unlikely(!prometheus_exporter_instance || !prometheus_exporter_instance->config.initialized))
         return;
 
     prometheus_exporter_instance->before = now_realtime_sec();
