@@ -12,6 +12,7 @@
 #define HEALTH_FAMILIES_KEY "families"
 #define HEALTH_PLUGIN_KEY "plugin"
 #define HEALTH_MODULE_KEY "module"
+#define HEALTH_CHARTS_KEY "charts"
 #define HEALTH_LOOKUP_KEY "lookup"
 #define HEALTH_CALC_KEY "calc"
 #define HEALTH_EVERY_KEY "every"
@@ -23,10 +24,14 @@
 #define HEALTH_RECIPIENT_KEY "to"
 #define HEALTH_UNITS_KEY "units"
 #define HEALTH_INFO_KEY "info"
+#define HEALTH_CLASS_KEY "class"
+#define HEALTH_COMPONENT_KEY "component"
+#define HEALTH_TYPE_KEY "type"
 #define HEALTH_DELAY_KEY "delay"
 #define HEALTH_OPTIONS_KEY "options"
 #define HEALTH_REPEAT_KEY "repeat"
 #define HEALTH_HOST_LABEL_KEY "host labels"
+#define HEALTH_FOREACH_KEY "foreach"
 
 static inline int rrdcalc_add_alarm_from_config(RRDHOST *host, RRDCALC *rc) {
     if(!rc->chart) {
@@ -384,7 +389,7 @@ static inline int health_parse_db_lookup(
     }
 
     // sane defaults
-    *every = abs(*after);
+    *every = ABS(*after);
 
     // now we may have optional parameters
     while(*s) {
@@ -468,6 +473,30 @@ static inline char *health_source_file(size_t line, const char *file) {
     return strdupz(buffer);
 }
 
+char *health_edit_command_from_source(const char *source)
+{
+    char buffer[FILENAME_MAX + 1];
+    char *temp = strdupz(source);
+    char *line_num = strchr(temp, '@');
+    char *file_no_path = strrchr(temp, '/');
+
+    if (likely(file_no_path && line_num)) {
+        *line_num = '\0';
+        snprintfz(
+            buffer,
+            FILENAME_MAX,
+            "sudo %s/edit-config health.d/%s=%s=%s",
+            netdata_configured_user_config_dir,
+            file_no_path + 1,
+            temp,
+            localhost->registry_hostname);
+    } else
+        buffer[0] = '\0';
+
+    freez(temp);
+    return strdupz(buffer);
+}
+
 static inline void strip_quotes(char *s) {
     while(*s) {
         if(*s == '\'' || *s == '"') *s = ' ';
@@ -475,6 +504,40 @@ static inline void strip_quotes(char *s) {
     }
 }
 
+static inline void alert_config_free(struct alert_config *cfg)
+{
+    freez(cfg->alarm);
+    freez(cfg->template_key);
+    freez(cfg->os);
+    freez(cfg->host);
+    freez(cfg->on);
+    freez(cfg->families);
+    freez(cfg->plugin);
+    freez(cfg->module);
+    freez(cfg->charts);
+    freez(cfg->lookup);
+    freez(cfg->calc);
+    freez(cfg->warn);
+    freez(cfg->crit);
+    freez(cfg->every);
+    freez(cfg->green);
+    freez(cfg->red);
+    freez(cfg->exec);
+    freez(cfg->to);
+    freez(cfg->units);
+    freez(cfg->info);
+    freez(cfg->classification);
+    freez(cfg->component);
+    freez(cfg->type);
+    freez(cfg->delay);
+    freez(cfg->options);
+    freez(cfg->repeat);
+    freez(cfg->host_labels);
+    freez(cfg->p_db_lookup_dimensions);
+    freez(cfg->p_db_lookup_method);
+    freez(cfg);
+}
+
 static int health_readfile(const char *filename, void *data) {
     RRDHOST *host = (RRDHOST *)data;
 
@@ -489,6 +552,7 @@ static int health_readfile(const char *filename, void *data) {
             hash_families = 0,
             hash_plugin = 0,
             hash_module = 0,
+            hash_charts = 0,
             hash_calc = 0,
             hash_green = 0,
             hash_red = 0,
@@ -499,6 +563,9 @@ static int health_readfile(const char *filename, void *data) {
             hash_lookup = 0,
             hash_units = 0,
             hash_info = 0,
+            hash_class = 0,
+            hash_component = 0,
+            hash_type = 0,
             hash_recipient = 0,
             hash_delay = 0,
             hash_options = 0,
@@ -516,6 +583,7 @@ static int health_readfile(const char *filename, void *data) {
         hash_families = simple_uhash(HEALTH_FAMILIES_KEY);
         hash_plugin = simple_uhash(HEALTH_PLUGIN_KEY);
         hash_module = simple_uhash(HEALTH_MODULE_KEY);
+        hash_charts = simple_uhash(HEALTH_CHARTS_KEY);
         hash_calc = simple_uhash(HEALTH_CALC_KEY);
         hash_lookup = simple_uhash(HEALTH_LOOKUP_KEY);
         hash_green = simple_uhash(HEALTH_GREEN_KEY);
@@ -526,6 +594,9 @@ static int health_readfile(const char *filename, void *data) {
         hash_every = simple_uhash(HEALTH_EVERY_KEY);
         hash_units = simple_hash(HEALTH_UNITS_KEY);
         hash_info = simple_hash(HEALTH_INFO_KEY);
+        hash_class = simple_uhash(HEALTH_CLASS_KEY);
+        hash_component = simple_uhash(HEALTH_COMPONENT_KEY);
+        hash_type = simple_uhash(HEALTH_TYPE_KEY);
         hash_recipient = simple_hash(HEALTH_RECIPIENT_KEY);
         hash_delay = simple_uhash(HEALTH_DELAY_KEY);
         hash_options = simple_uhash(HEALTH_OPTIONS_KEY);
@@ -541,6 +612,7 @@ static int health_readfile(const char *filename, void *data) {
 
     RRDCALC *rc = NULL;
     RRDCALCTEMPLATE *rt = NULL;
+    struct alert_config *alert_cfg = NULL;
 
     int ignore_this = 0;
     size_t line = 0, append = 0;
@@ -590,16 +662,18 @@ static int health_readfile(const char *filename, void *data) {
 
         if(hash == hash_alarm && !strcasecmp(key, HEALTH_ALARM_KEY)) {
             if(rc) {
-                if(ignore_this || !rrdcalc_add_alarm_from_config(host, rc)) {
+                if(ignore_this || !alert_hash_and_store_config(rc->config_hash_id, alert_cfg) || !rrdcalc_add_alarm_from_config(host, rc)) {
                     rrdcalc_free(rc);
+                    alert_config_free(alert_cfg);
                 }
                // health_add_alarms_loop(host, rc, ignore_this) ;
             }
 
             if(rt) {
-                if (ignore_this || !rrdcalctemplate_add_template_from_config(host, rt))
+                if (ignore_this || !alert_hash_and_store_config(rt->config_hash_id, alert_cfg) || !rrdcalctemplate_add_template_from_config(host, rt)) {
                     rrdcalctemplate_free(rt);
-
+                    alert_config_free(alert_cfg);
+                }
                 rt = NULL;
             }
 
@@ -616,25 +690,30 @@ static int health_readfile(const char *filename, void *data) {
             rc->old_status = RRDCALC_STATUS_UNINITIALIZED;
             rc->warn_repeat_every = host->health_default_warn_repeat_every;
             rc->crit_repeat_every = host->health_default_crit_repeat_every;
+            alert_cfg = callocz(1, sizeof(struct alert_config));
 
             if(rrdvar_fix_name(rc->name))
                 error("Health configuration renamed alarm '%s' to '%s'", value, rc->name);
 
+            alert_cfg->alarm = strdupz(rc->name);
             ignore_this = 0;
         }
         else if(hash == hash_template && !strcasecmp(key, HEALTH_TEMPLATE_KEY)) {
             if(rc) {
 //                health_add_alarms_loop(host, rc, ignore_this) ;
-                if(ignore_this || !rrdcalc_add_alarm_from_config(host, rc)) {
+                if(ignore_this || !alert_hash_and_store_config(rc->config_hash_id, alert_cfg) || !rrdcalc_add_alarm_from_config(host, rc)) {
                     rrdcalc_free(rc);
+                    alert_config_free(alert_cfg);
                 }
 
                 rc = NULL;
             }
 
             if(rt) {
-                if(ignore_this || !rrdcalctemplate_add_template_from_config(host, rt))
+                if(ignore_this || !alert_hash_and_store_config(rt->config_hash_id, alert_cfg) || !rrdcalctemplate_add_template_from_config(host, rt)) {
                     rrdcalctemplate_free(rt);
+                    alert_config_free(alert_cfg);
+                }
             }
 
             rt = callocz(1, sizeof(RRDCALCTEMPLATE));
@@ -646,14 +725,17 @@ static int health_readfile(const char *filename, void *data) {
             rt->delay_multiplier = 1.0;
             rt->warn_repeat_every = host->health_default_warn_repeat_every;
             rt->crit_repeat_every = host->health_default_crit_repeat_every;
+            alert_cfg = callocz(1, sizeof(struct alert_config));
 
             if(rrdvar_fix_name(rt->name))
                 error("Health configuration renamed template '%s' to '%s'", value, rt->name);
 
+            alert_cfg->template_key = strdupz(rt->name);
             ignore_this = 0;
         }
         else if(hash == hash_os && !strcasecmp(key, HEALTH_OS_KEY)) {
             char *os_match = value;
+            if (alert_cfg) alert_cfg->os = strdupz(value);
             SIMPLE_PATTERN *os_pattern = simple_pattern_create(os_match, NULL, SIMPLE_PATTERN_EXACT);
 
             if(!simple_pattern_matches(os_pattern, host->os)) {
@@ -670,6 +752,7 @@ static int health_readfile(const char *filename, void *data) {
         }
         else if(hash == hash_host && !strcasecmp(key, HEALTH_HOST_KEY)) {
             char *host_match = value;
+            if (alert_cfg) alert_cfg->host = strdupz(value);
             SIMPLE_PATTERN *host_pattern = simple_pattern_create(host_match, NULL, SIMPLE_PATTERN_EXACT);
 
             if(!simple_pattern_matches(host_pattern, host->hostname)) {
@@ -686,6 +769,7 @@ static int health_readfile(const char *filename, void *data) {
         }
         else if(rc) {
             if(hash == hash_on && !strcasecmp(key, HEALTH_ON_KEY)) {
+                alert_cfg->on = strdupz(value);
                 if(rc->chart) {
                     if(strcmp(rc->chart, value) != 0)
                         error("Health configuration at line %zu of file '%s' for alarm '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
@@ -696,19 +780,69 @@ static int health_readfile(const char *filename, void *data) {
                 rc->chart = strdupz(value);
                 rc->hash_chart = simple_hash(rc->chart);
             }
+            else if(hash == hash_class && !strcasecmp(key, HEALTH_CLASS_KEY)) {
+                alert_cfg->classification = strdupz(value);
+                if(rc->classification) {
+                    if(strcmp(rc->classification, value) != 0)
+                        error("Health configuration at line %zu of file '%s' for alarm '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
+                                line, filename, rc->name, key, rc->classification, value, value);
+
+                    freez(rc->classification);
+                }
+                rc->classification = strdupz(value);
+                strip_quotes(rc->classification);
+            }
+            else if(hash == hash_component && !strcasecmp(key, HEALTH_COMPONENT_KEY)) {
+                alert_cfg->component = strdupz(value);
+                if(rc->component) {
+                    if(strcmp(rc->component, value) != 0)
+                        error("Health configuration at line %zu of file '%s' for alarm '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
+                                line, filename, rc->name, key, rc->component, value, value);
+
+                    freez(rc->component);
+                }
+                rc->component = strdupz(value);
+                strip_quotes(rc->component);
+            }
+            else if(hash == hash_type && !strcasecmp(key, HEALTH_TYPE_KEY)) {
+                alert_cfg->type = strdupz(value);
+                if(rc->type) {
+                    if(strcmp(rc->type, value) != 0)
+                        error("Health configuration at line %zu of file '%s' for alarm '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
+                                line, filename, rc->name, key, rc->type, value, value);
+
+                    freez(rc->type);
+                }
+                rc->type = strdupz(value);
+                strip_quotes(rc->type);
+            }
             else if(hash == hash_lookup && !strcasecmp(key, HEALTH_LOOKUP_KEY)) {
+                alert_cfg->lookup = strdupz(value);
                 health_parse_db_lookup(line, filename, value, &rc->group, &rc->after, &rc->before,
                         &rc->update_every, &rc->options, &rc->dimensions, &rc->foreachdim);
                 if(rc->foreachdim) {
                     rc->spdim = health_pattern_from_foreach(rc->foreachdim);
                 }
+                if (rc->after) {
+                    if (rc->dimensions)
+                        alert_cfg->p_db_lookup_dimensions = strdupz(rc->dimensions);
+                    if (rc->group)
+                        alert_cfg->p_db_lookup_method = strdupz(group_method2string(rc->group));
+                    alert_cfg->p_db_lookup_options = rc->options;
+                    alert_cfg->p_db_lookup_after = rc->after;
+                    alert_cfg->p_db_lookup_before = rc->before;
+                    alert_cfg->p_update_every = rc->update_every;
+                }
             }
             else if(hash == hash_every && !strcasecmp(key, HEALTH_EVERY_KEY)) {
+                alert_cfg->every = strdupz(value);
                 if(!config_parse_duration(value, &rc->update_every))
                     error("Health configuration at line %zu of file '%s' for alarm '%s' at key '%s' cannot parse duration: '%s'.",
                             line, filename, rc->name, key, value);
+                alert_cfg->p_update_every = rc->update_every;
             }
             else if(hash == hash_green && !strcasecmp(key, HEALTH_GREEN_KEY)) {
+                alert_cfg->green = strdupz(value);
                 char *e;
                 rc->green = str2ld(value, &e);
                 if(e && *e) {
@@ -717,6 +851,7 @@ static int health_readfile(const char *filename, void *data) {
                 }
             }
             else if(hash == hash_red && !strcasecmp(key, HEALTH_RED_KEY)) {
+                alert_cfg->red = strdupz(value);
                 char *e;
                 rc->red = str2ld(value, &e);
                 if(e && *e) {
@@ -725,6 +860,7 @@ static int health_readfile(const char *filename, void *data) {
                 }
             }
             else if(hash == hash_calc && !strcasecmp(key, HEALTH_CALC_KEY)) {
+                alert_cfg->calc = strdupz(value);
                 const char *failed_at = NULL;
                 int error = 0;
                 rc->calculation = expression_parse(value, &failed_at, &error);
@@ -734,6 +870,7 @@ static int health_readfile(const char *filename, void *data) {
                 }
             }
             else if(hash == hash_warn && !strcasecmp(key, HEALTH_WARN_KEY)) {
+                alert_cfg->warn = strdupz(value);
                 const char *failed_at = NULL;
                 int error = 0;
                 rc->warning = expression_parse(value, &failed_at, &error);
@@ -743,6 +880,7 @@ static int health_readfile(const char *filename, void *data) {
                 }
             }
             else if(hash == hash_crit && !strcasecmp(key, HEALTH_CRIT_KEY)) {
+                alert_cfg->crit = strdupz(value);
                 const char *failed_at = NULL;
                 int error = 0;
                 rc->critical = expression_parse(value, &failed_at, &error);
@@ -752,6 +890,7 @@ static int health_readfile(const char *filename, void *data) {
                 }
             }
             else if(hash == hash_exec && !strcasecmp(key, HEALTH_EXEC_KEY)) {
+                alert_cfg->exec = strdupz(value);
                 if(rc->exec) {
                     if(strcmp(rc->exec, value) != 0)
                         error("Health configuration at line %zu of file '%s' for alarm '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
@@ -762,6 +901,7 @@ static int health_readfile(const char *filename, void *data) {
                 rc->exec = strdupz(value);
             }
             else if(hash == hash_recipient && !strcasecmp(key, HEALTH_RECIPIENT_KEY)) {
+                alert_cfg->to = strdupz(value);
                 if(rc->recipient) {
                     if(strcmp(rc->recipient, value) != 0)
                         error("Health configuration at line %zu of file '%s' for alarm '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
@@ -772,6 +912,7 @@ static int health_readfile(const char *filename, void *data) {
                 rc->recipient = strdupz(value);
             }
             else if(hash == hash_units && !strcasecmp(key, HEALTH_UNITS_KEY)) {
+                alert_cfg->units = strdupz(value);
                 if(rc->units) {
                     if(strcmp(rc->units, value) != 0)
                         error("Health configuration at line %zu of file '%s' for alarm '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
@@ -783,6 +924,7 @@ static int health_readfile(const char *filename, void *data) {
                 strip_quotes(rc->units);
             }
             else if(hash == hash_info && !strcasecmp(key, HEALTH_INFO_KEY)) {
+                alert_cfg->info = strdupz(value);
                 if(rc->info) {
                     if(strcmp(rc->info, value) != 0)
                         error("Health configuration at line %zu of file '%s' for alarm '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
@@ -794,17 +936,21 @@ static int health_readfile(const char *filename, void *data) {
                 strip_quotes(rc->info);
             }
             else if(hash == hash_delay && !strcasecmp(key, HEALTH_DELAY_KEY)) {
+                alert_cfg->delay = strdupz(value);
                 health_parse_delay(line, filename, value, &rc->delay_up_duration, &rc->delay_down_duration, &rc->delay_max_duration, &rc->delay_multiplier);
             }
             else if(hash == hash_options && !strcasecmp(key, HEALTH_OPTIONS_KEY)) {
+                alert_cfg->options = strdupz(value);
                 rc->options |= health_parse_options(value);
             }
             else if(hash == hash_repeat && !strcasecmp(key, HEALTH_REPEAT_KEY)){
+                alert_cfg->repeat = strdupz(value);
                 health_parse_repeat(line, filename, value,
                                     &rc->warn_repeat_every,
                                     &rc->crit_repeat_every);
             }
             else if(hash == hash_host_label && !strcasecmp(key, HEALTH_HOST_LABEL_KEY)) {
+                alert_cfg->host_labels = strdupz(value);
                 if(rc->labels) {
                     if(strcmp(rc->labels, value) != 0)
                         error("Health configuration at line %zu of file '%s' for alarm '%s' has key '%s' twice, once with value '%s' and later with value '%s'.",
@@ -818,6 +964,7 @@ static int health_readfile(const char *filename, void *data) {
                 rc->splabels = simple_pattern_create(rc->labels, NULL, SIMPLE_PATTERN_EXACT);
             }
             else if(hash == hash_plugin && !strcasecmp(key, HEALTH_PLUGIN_KEY)) {
+                alert_cfg->plugin = strdupz(value);
                 freez(rc->plugin_match);
                 simple_pattern_free(rc->plugin_pattern);
 
@@ -825,6 +972,7 @@ static int health_readfile(const char *filename, void *data) {
                 rc->plugin_pattern = simple_pattern_create(rc->plugin_match, NULL, SIMPLE_PATTERN_EXACT);
             }
             else if(hash == hash_module && !strcasecmp(key, HEALTH_MODULE_KEY)) {
+                alert_cfg->module = strdupz(value);
                 freez(rc->module_match);
                 simple_pattern_free(rc->module_pattern);
 
@@ -838,6 +986,7 @@ static int health_readfile(const char *filename, void *data) {
         }
         else if(rt) {
             if(hash == hash_on && !strcasecmp(key, HEALTH_ON_KEY)) {
+                alert_cfg->on = strdupz(value);
                 if(rt->context) {
                     if(strcmp(rt->context, value) != 0)
                         error("Health configuration at line %zu of file '%s' for template '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
@@ -848,7 +997,44 @@ static int health_readfile(const char *filename, void *data) {
                 rt->context = strdupz(value);
                 rt->hash_context = simple_hash(rt->context);
             }
+            else if(hash == hash_class && !strcasecmp(key, HEALTH_CLASS_KEY)) {
+                alert_cfg->classification = strdupz(value);
+                if(rt->classification) {
+                    if(strcmp(rt->classification, value) != 0)
+                        error("Health configuration at line %zu of file '%s' for alarm '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
+                              line, filename, rt->name, key, rt->classification, value, value);
+
+                    freez(rt->classification);
+                }
+                rt->classification = strdupz(value);
+                strip_quotes(rt->classification);
+            }
+            else if(hash == hash_component && !strcasecmp(key, HEALTH_COMPONENT_KEY)) {
+                alert_cfg->component = strdupz(value);
+                if(rt->component) {
+                    if(strcmp(rt->component, value) != 0)
+                        error("Health configuration at line %zu of file '%s' for alarm '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
+                              line, filename, rt->name, key, rt->component, value, value);
+
+                    freez(rt->component);
+                }
+                rt->component = strdupz(value);
+                strip_quotes(rt->component);
+            }
+            else if(hash == hash_type && !strcasecmp(key, HEALTH_TYPE_KEY)) {
+                alert_cfg->type = strdupz(value);
+                if(rt->type) {
+                    if(strcmp(rt->type, value) != 0)
+                        error("Health configuration at line %zu of file '%s' for alarm '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
+                              line, filename, rt->name, key, rt->type, value, value);
+
+                    freez(rt->type);
+                }
+                rt->type = strdupz(value);
+                strip_quotes(rt->type);
+            }
             else if(hash == hash_families && !strcasecmp(key, HEALTH_FAMILIES_KEY)) {
+                alert_cfg->families = strdupz(value);
                 freez(rt->family_match);
                 simple_pattern_free(rt->family_pattern);
 
@@ -856,6 +1042,7 @@ static int health_readfile(const char *filename, void *data) {
                 rt->family_pattern = simple_pattern_create(rt->family_match, NULL, SIMPLE_PATTERN_EXACT);
             }
             else if(hash == hash_plugin && !strcasecmp(key, HEALTH_PLUGIN_KEY)) {
+                alert_cfg->plugin = strdupz(value);
                 freez(rt->plugin_match);
                 simple_pattern_free(rt->plugin_pattern);
 
@@ -863,25 +1050,48 @@ static int health_readfile(const char *filename, void *data) {
                 rt->plugin_pattern = simple_pattern_create(rt->plugin_match, NULL, SIMPLE_PATTERN_EXACT);
             }
             else if(hash == hash_module && !strcasecmp(key, HEALTH_MODULE_KEY)) {
+                alert_cfg->module = strdupz(value);
                 freez(rt->module_match);
                 simple_pattern_free(rt->module_pattern);
 
                 rt->module_match = strdupz(value);
                 rt->module_pattern = simple_pattern_create(rt->module_match, NULL, SIMPLE_PATTERN_EXACT);
             }
+            else if(hash == hash_charts && !strcasecmp(key, HEALTH_CHARTS_KEY)) {
+                alert_cfg->charts = strdupz(value);
+                freez(rt->charts_match);
+                simple_pattern_free(rt->charts_pattern);
+
+                rt->charts_match = strdupz(value);
+                rt->charts_pattern = simple_pattern_create(rt->charts_match, NULL, SIMPLE_PATTERN_EXACT);
+            }
             else if(hash == hash_lookup && !strcasecmp(key, HEALTH_LOOKUP_KEY)) {
+                alert_cfg->lookup = strdupz(value);
                 health_parse_db_lookup(line, filename, value, &rt->group, &rt->after, &rt->before,
                         &rt->update_every, &rt->options, &rt->dimensions, &rt->foreachdim);
                 if(rt->foreachdim) {
                     rt->spdim = health_pattern_from_foreach(rt->foreachdim);
                 }
+                if (rt->after) {
+                    if (rt->dimensions)
+                        alert_cfg->p_db_lookup_dimensions = strdupz(rt->dimensions);
+                    if (rt->group)
+                        alert_cfg->p_db_lookup_method = strdupz(group_method2string(rt->group));
+                    alert_cfg->p_db_lookup_options = rt->options;
+                    alert_cfg->p_db_lookup_after = rt->after;
+                    alert_cfg->p_db_lookup_before = rt->before;
+                    alert_cfg->p_update_every = rt->update_every;
+                }
             }
             else if(hash == hash_every && !strcasecmp(key, HEALTH_EVERY_KEY)) {
+                alert_cfg->every = strdupz(value);
                 if(!config_parse_duration(value, &rt->update_every))
                     error("Health configuration at line %zu of file '%s' for template '%s' at key '%s' cannot parse duration: '%s'.",
                             line, filename, rt->name, key, value);
+                alert_cfg->p_update_every = rt->update_every;
             }
             else if(hash == hash_green && !strcasecmp(key, HEALTH_GREEN_KEY)) {
+                alert_cfg->green = strdupz(value);
                 char *e;
                 rt->green = str2ld(value, &e);
                 if(e && *e) {
@@ -890,6 +1100,7 @@ static int health_readfile(const char *filename, void *data) {
                 }
             }
             else if(hash == hash_red && !strcasecmp(key, HEALTH_RED_KEY)) {
+                alert_cfg->red = strdupz(value);
                 char *e;
                 rt->red = str2ld(value, &e);
                 if(e && *e) {
@@ -898,6 +1109,7 @@ static int health_readfile(const char *filename, void *data) {
                 }
             }
             else if(hash == hash_calc && !strcasecmp(key, HEALTH_CALC_KEY)) {
+                alert_cfg->calc = strdupz(value);
                 const char *failed_at = NULL;
                 int error = 0;
                 rt->calculation = expression_parse(value, &failed_at, &error);
@@ -907,6 +1119,7 @@ static int health_readfile(const char *filename, void *data) {
                 }
             }
             else if(hash == hash_warn && !strcasecmp(key, HEALTH_WARN_KEY)) {
+                alert_cfg->warn = strdupz(value);
                 const char *failed_at = NULL;
                 int error = 0;
                 rt->warning = expression_parse(value, &failed_at, &error);
@@ -916,6 +1129,7 @@ static int health_readfile(const char *filename, void *data) {
                 }
             }
             else if(hash == hash_crit && !strcasecmp(key, HEALTH_CRIT_KEY)) {
+                alert_cfg->crit = strdupz(value);
                 const char *failed_at = NULL;
                 int error = 0;
                 rt->critical = expression_parse(value, &failed_at, &error);
@@ -925,6 +1139,7 @@ static int health_readfile(const char *filename, void *data) {
                 }
             }
             else if(hash == hash_exec && !strcasecmp(key, HEALTH_EXEC_KEY)) {
+                alert_cfg->exec = strdupz(value);
                 if(rt->exec) {
                     if(strcmp(rt->exec, value) != 0)
                         error("Health configuration at line %zu of file '%s' for template '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
@@ -935,6 +1150,7 @@ static int health_readfile(const char *filename, void *data) {
                 rt->exec = strdupz(value);
             }
             else if(hash == hash_recipient && !strcasecmp(key, HEALTH_RECIPIENT_KEY)) {
+                alert_cfg->to = strdupz(value);
                 if(rt->recipient) {
                     if(strcmp(rt->recipient, value) != 0)
                         error("Health configuration at line %zu of file '%s' for template '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
@@ -945,6 +1161,7 @@ static int health_readfile(const char *filename, void *data) {
                 rt->recipient = strdupz(value);
             }
             else if(hash == hash_units && !strcasecmp(key, HEALTH_UNITS_KEY)) {
+                alert_cfg->units = strdupz(value);
                 if(rt->units) {
                     if(strcmp(rt->units, value) != 0)
                         error("Health configuration at line %zu of file '%s' for template '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
@@ -956,6 +1173,7 @@ static int health_readfile(const char *filename, void *data) {
                 strip_quotes(rt->units);
             }
             else if(hash == hash_info && !strcasecmp(key, HEALTH_INFO_KEY)) {
+                alert_cfg->info = strdupz(value);
                 if(rt->info) {
                     if(strcmp(rt->info, value) != 0)
                         error("Health configuration at line %zu of file '%s' for template '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
@@ -967,17 +1185,21 @@ static int health_readfile(const char *filename, void *data) {
                 strip_quotes(rt->info);
             }
             else if(hash == hash_delay && !strcasecmp(key, HEALTH_DELAY_KEY)) {
+                alert_cfg->delay = strdupz(value);
                 health_parse_delay(line, filename, value, &rt->delay_up_duration, &rt->delay_down_duration, &rt->delay_max_duration, &rt->delay_multiplier);
             }
             else if(hash == hash_options && !strcasecmp(key, HEALTH_OPTIONS_KEY)) {
+                alert_cfg->options = strdupz(value);
                 rt->options |= health_parse_options(value);
             }
             else if(hash == hash_repeat && !strcasecmp(key, HEALTH_REPEAT_KEY)){
+                alert_cfg->repeat = strdupz(value);
                 health_parse_repeat(line, filename, value,
                                     &rt->warn_repeat_every,
                                     &rt->crit_repeat_every);
             }
             else if(hash == hash_host_label && !strcasecmp(key, HEALTH_HOST_LABEL_KEY)) {
+                alert_cfg->host_labels = strdupz(value);
                 if(rt->labels) {
                     if(strcmp(rt->labels, value) != 0)
                         error("Health configuration at line %zu of file '%s' for template '%s' has key '%s' twice, once with value '%s' and later with value '%s'. Using ('%s').",
@@ -1003,16 +1225,20 @@ static int health_readfile(const char *filename, void *data) {
 
     if(rc) {
         //health_add_alarms_loop(host, rc, ignore_this) ;
-        if(ignore_this || !rrdcalc_add_alarm_from_config(host, rc)) {
+        if(ignore_this || !alert_hash_and_store_config(rc->config_hash_id, alert_cfg) || !rrdcalc_add_alarm_from_config(host, rc)) {
             rrdcalc_free(rc);
         }
     }
 
     if(rt) {
-        if(ignore_this || !rrdcalctemplate_add_template_from_config(host, rt))
+        if(ignore_this || !alert_hash_and_store_config(rt->config_hash_id, alert_cfg) || !rrdcalctemplate_add_template_from_config(host, rt)) {
             rrdcalctemplate_free(rt);
+        }
     }
 
+    if (alert_cfg)
+        alert_config_free(alert_cfg);
+
     fclose(fp);
     return 1;
 }
