@@ -91,6 +91,7 @@
 #define CONFIG_SECTION_HEALTH     "health"
 #define CONFIG_SECTION_BACKEND    "backend"
 #define CONFIG_SECTION_STREAM     "stream"
+#define CONFIG_SECTION_ML         "ml"
 #define CONFIG_SECTION_EXPORTING  "exporting:global"
 #define CONFIG_SECTION_PROMETHEUS "prometheus:exporter"
 #define CONFIG_SECTION_HOST_LABEL "host labels"
@@ -111,7 +112,7 @@
 #define CONFIG_VALUE_CHECKED 0x08 // has been checked if the value is different from the default
 
 struct config_option {
-    avl avl_node;           // the index entry of this entry - this has to be first!
+    avl_t avl_node;         // the index entry of this entry - this has to be first!
 
     uint8_t flags;
     uint32_t hash;          // a simple hash to speed up searching
@@ -124,14 +125,14 @@ struct config_option {
 };
 
 struct section {
-    avl avl_node;           // the index entry of this section - this has to be first!
+    avl_t avl_node;         // the index entry of this section - this has to be first!
 
     uint32_t hash;          // a simple hash to speed up searching
                             // we first compare hashes, and only if the hashes are equal we do string comparisons
 
     char *name;
 
-    struct section *next;    // gloabl config_mutex protects just this
+    struct section *next;    // global config_mutex protects just this
 
     struct config_option *values;
     avl_tree_lock values_index;
