@@ -38,6 +38,9 @@ if [ ! -f ../../netdata-installer.sh ]; then
   exit $?
 fi
 
+git clean -dxf
+git submodule foreach --recursive git clean -dxf
+
 cat >&2 << EOF
 This program will create a self-extracting shell package containing
 a statically linked netdata, able to run on any 64bit Linux system,
@@ -49,6 +52,12 @@ EOF
 
 if [ ! -d tmp ]; then
   mkdir tmp || exit 1
+else
+  rm -rf tmp/*
+fi
+
+if [ -z "${GITHUB_ACTIONS}" ]; then
+    export GITHUB_ACTIONS=false
 fi
 
 if ! ./run-all-jobs.sh "$@"; then
