@@ -65,6 +65,8 @@ extern int rrdset2anything_api_v1(
         , long group_time
         , uint32_t options
         , time_t *latest_timestamp
+        , struct context_param *context_param_list
+        , char *chart_label_key
 );
 
 extern int rrdset2value_api_v1(
@@ -83,4 +85,8 @@ extern int rrdset2value_api_v1(
         , int *value_is_null
 );
 
+extern void build_context_param_list(struct context_param **param_list, RRDSET *st);
+extern void rebuild_context_param_list(struct context_param *context_param_list, time_t after_requested);
+extern void free_context_param_list(struct context_param **param_list);
+
 #endif /* NETDATA_RRD2JSON_H */
