@@ -3,6 +3,7 @@
 #include "web_api_v1.h"
 
 char *api_secret;
+extern int aclk_use_new_cloud_arch;
 
 static struct {
     const char *name;
@@ -36,6 +37,7 @@ static struct {
         , {"match-names"     , 0    , RRDR_OPTION_MATCH_NAMES}
         , {"showcustomvars"  , 0    , RRDR_OPTION_CUSTOM_VARS}
         , {"allow_past"      , 0    , RRDR_OPTION_ALLOW_PAST}
+        , {"anomaly-bit"     , 0    , RRDR_OPTION_ANOMALY_BIT}
         , {                  NULL, 0, 0}
 };
 
@@ -276,6 +278,7 @@ inline int web_client_api_request_v1_alarm_count(RRDHOST *host, struct web_clien
 
 inline int web_client_api_request_v1_alarm_log(RRDHOST *host, struct web_client *w, char *url) {
     uint32_t after = 0;
+    char *chart = NULL;
 
     while(url) {
         char *value = mystrsep(&url, "&");
@@ -285,12 +288,13 @@ inline int web_client_api_request_v1_alarm_log(RRDHOST *host, struct web_client
         if(!name || !*name) continue;
         if(!value || !*value) continue;
 
-        if(!strcmp(name, "after")) after = (uint32_t)strtoul(value, NULL, 0);
+        if (!strcmp(name, "after")) after = (uint32_t)strtoul(value, NULL, 0);
+        else if (!strcmp(name, "chart")) chart = value;
     }
 
     buffer_flush(w->response.data);
     w->response.data->contenttype = CT_APPLICATION_JSON;
-    health_alarm_log2json(host, w->response.data, after);
+    health_alarm_log2json(host, w->response.data, after, chart);
     return HTTP_RESP_OK;
 }
 
@@ -511,6 +515,10 @@ inline int web_client_api_request_v1_data(RRDHOST *host, struct web_client *w, c
         rrdhost_unlock(host);
         if (likely(context_param_list && context_param_list->rd))  // Just set the first one
             st = context_param_list->rd->rrdset;
+        else {
+            if (!chart_label_key)
+                sql_build_context_param_list(&context_param_list, host, context, NULL);
+        }
     }
     else {
         st = rrdset_find(host, chart);
@@ -518,6 +526,17 @@ inline int web_client_api_request_v1_data(RRDHOST *host, struct web_client *w, c
             st = rrdset_find_byname(host, chart);
         if (likely(st))
             st->last_accessed_time = now_realtime_sec();
+        else
+            sql_build_context_param_list(&context_param_list, host, NULL, chart);
+    }
+
+    if (!st) {
+        if (likely(context_param_list && context_param_list->rd && context_param_list->rd->rrdset))
+            st = context_param_list->rd->rrdset;
+        else {
+            free_context_param_list(&context_param_list);
+            context_param_list = NULL;
+        }
     }
 
     if (!st && !context_param_list) {
@@ -571,9 +590,13 @@ inline int web_client_api_request_v1_data(RRDHOST *host, struct web_client *w, c
                 w->id, google_version, google_reqId, google_sig, google_out, responseHandler, outFileName
         );
 
-        buffer_sprintf(w->response.data,
-                "%s({version:'%s',reqId:'%s',status:'ok',sig:'%ld',table:",
-                responseHandler, google_version, google_reqId, st->last_updated.tv_sec);
+        buffer_sprintf(
+            w->response.data,
+            "%s({version:'%s',reqId:'%s',status:'ok',sig:'%"PRId64"',table:",
+            responseHandler,
+            google_version,
+            google_reqId,
+            (int64_t)st->last_updated.tv_sec);
     }
     else if(format == DATASOURCE_JSONP) {
         if(responseHandler == NULL)
@@ -733,6 +756,7 @@ inline int web_client_api_request_v1_registry(RRDHOST *host, struct web_client *
 
     if(unlikely(action == 'H')) {
         // HELLO request, dashboard ACL
+        analytics_log_dashboard();
         if(unlikely(!web_client_can_access_dashboard(w)))
             return web_client_permission_denied(w);
     }
@@ -849,8 +873,8 @@ static inline void web_client_api_request_v1_info_mirrored_hosts(BUFFER *wb) {
 
         netdata_mutex_lock(&host->receiver_lock);
         buffer_sprintf(
-            wb, "\t\t{ \"guid\": \"%s\", \"reachable\": %s, \"claim_id\": ", host->machine_guid,
-            (host->receiver || host == localhost) ? "true" : "false");
+            wb, "\t\t{ \"guid\": \"%s\", \"reachable\": %s, \"hops\": %d, \"claim_id\": ", host->machine_guid,
+            (host->receiver || host == localhost) ? "true" : "false", host->system_info ? host->system_info->hops : (host == localhost) ? 0 : 1);
         netdata_mutex_unlock(&host->receiver_lock);
 
         rrdhost_aclk_state_lock(host);
@@ -961,8 +985,18 @@ inline int web_client_api_request_v1_info_fill_buffer(RRDHOST *host, BUFFER *wb)
 
 #ifdef ENABLE_ACLK
     buffer_strcat(wb, "\t\"cloud-available\": true,\n");
+    buffer_strcat(wb, "\t\"aclk-ng-available\": true,\n");
+#ifdef ENABLE_NEW_CLOUD_PROTOCOL
+    buffer_strcat(wb, "\t\"aclk-ng-new-cloud-protocol\": true,\n");
+#else
+    buffer_strcat(wb, "\t\"aclk-ng-new-cloud-protocol\": false,\n");
+#endif
+    buffer_strcat(wb, "\t\"aclk-legacy-available\": false,\n");
+    buffer_strcat(wb, "\t\"aclk-implementation\": \"Next Generation\",\n");
 #else
     buffer_strcat(wb, "\t\"cloud-available\": false,\n");
+    buffer_strcat(wb, "\t\"aclk-ng-available\": false,\n");
+    buffer_strcat(wb, "\t\"aclk-legacy-available\": false,\n");
 #endif
     char *agent_id = is_agent_claimed();
     if (agent_id == NULL)
@@ -972,16 +1006,221 @@ inline int web_client_api_request_v1_info_fill_buffer(RRDHOST *host, BUFFER *wb)
         freez(agent_id);
     }
 #ifdef ENABLE_ACLK
-    if (aclk_connected)
-        buffer_strcat(wb, "\t\"aclk-available\": true\n");
+    if (aclk_connected) {
+        buffer_strcat(wb, "\t\"aclk-available\": true,\n");
+#ifdef ENABLE_NEW_CLOUD_PROTOCOL
+        if (aclk_use_new_cloud_arch)
+            buffer_strcat(wb, "\t\"aclk-available-protocol\": \"New\",\n");
+        else
+#endif
+            buffer_strcat(wb, "\t\"aclk-available-protocol\": \"Legacy\",\n");
+    }
     else
 #endif
-        buffer_strcat(wb, "\t\"aclk-available\": false\n");     // Intentionally valid with/without #ifdef above
+        buffer_strcat(wb, "\t\"aclk-available\": false,\n\t\"aclk-available-protocol\": null,\n");     // Intentionally valid with/without #ifdef above
 
-    buffer_strcat(wb, "}");
+    buffer_strcat(wb, "\t\"memory-mode\": ");
+    analytics_get_data(analytics_data.netdata_config_memory_mode, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"multidb-disk-quota\": ");
+    analytics_get_data(analytics_data.netdata_config_multidb_disk_quota, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"page-cache-size\": ");
+    analytics_get_data(analytics_data.netdata_config_page_cache_size, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"stream-enabled\": ");
+    analytics_get_data(analytics_data.netdata_config_stream_enabled, wb);
+    buffer_strcat(wb, ",\n");
+
+#ifdef  ENABLE_COMPRESSION
+    buffer_strcat(wb, "\t\"stream-compression\": ");
+    buffer_strcat(wb, (default_compression_enabled ? "\"enabled\"" : "\"disabled\""));
+    buffer_strcat(wb, ",\n");
+#else
+    buffer_strcat(wb, "\t\"stream-compression\": \"N/A\",\n");
+#endif  //ENABLE_COMPRESSION   
+
+    buffer_strcat(wb, "\t\"hosts-available\": ");
+    analytics_get_data(analytics_data.netdata_config_hosts_available, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"https-enabled\": ");
+    analytics_get_data(analytics_data.netdata_config_https_enabled, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"buildinfo\": ");
+    analytics_get_data(analytics_data.netdata_buildinfo, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"release-channel\": ");
+    analytics_get_data(analytics_data.netdata_config_release_channel, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"web-enabled\": ");
+    analytics_get_data(analytics_data.netdata_config_web_enabled, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"notification-methods\": ");
+    analytics_get_data(analytics_data.netdata_notification_methods, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"exporting-enabled\": ");
+    analytics_get_data(analytics_data.netdata_config_exporting_enabled, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"exporting-connectors\": ");
+    analytics_get_data(analytics_data.netdata_exporting_connectors, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"allmetrics-prometheus-used\": ");
+    analytics_get_data(analytics_data.netdata_allmetrics_prometheus_used, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"allmetrics-shell-used\": ");
+    analytics_get_data(analytics_data.netdata_allmetrics_shell_used, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"allmetrics-json-used\": ");
+    analytics_get_data(analytics_data.netdata_allmetrics_json_used, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"dashboard-used\": ");
+    analytics_get_data(analytics_data.netdata_dashboard_used, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"charts-count\": ");
+    analytics_get_data(analytics_data.netdata_charts_count, wb);
+    buffer_strcat(wb, ",\n");
+
+    buffer_strcat(wb, "\t\"metrics-count\": ");
+    analytics_get_data(analytics_data.netdata_metrics_count, wb);
+
+#if defined(ENABLE_ML)
+    buffer_strcat(wb, ",\n");
+    char *ml_info = ml_get_host_info(host);
+
+    buffer_strcat(wb, "\t\"ml-info\": ");
+    buffer_strcat(wb, ml_info);
+
+    free(ml_info);
+#endif
+
+    buffer_strcat(wb, "\n}");
     return 0;
 }
 
+#if defined(ENABLE_ML)
+int web_client_api_request_v1_anomaly_events(RRDHOST *host, struct web_client *w, char *url) {
+    if (!netdata_ready)
+        return HTTP_RESP_BACKEND_FETCH_FAILED;
+
+    uint32_t after = 0, before = 0;
+
+    while (url) {
+        char *value = mystrsep(&url, "&");
+        if (!value || !*value)
+            continue;
+
+        char *name = mystrsep(&value, "=");
+        if (!name || !*name)
+            continue;
+        if (!value || !*value)
+            continue;
+
+        if (!strcmp(name, "after"))
+            after = (uint32_t) (strtoul(value, NULL, 0) / 1000);
+        else if (!strcmp(name, "before"))
+            before = (uint32_t) (strtoul(value, NULL, 0) / 1000);
+    }
+
+    char *s;
+    if (!before || !after)
+        s = strdupz("{\"error\": \"missing after/before parameters\" }\n");
+    else {
+        s = ml_get_anomaly_events(host, "AD1", 1, after, before);
+        if (!s)
+            s = strdupz("{\"error\": \"json string is empty\" }\n");
+    }
+
+    BUFFER *wb = w->response.data;
+    buffer_flush(wb);
+
+    wb->contenttype = CT_APPLICATION_JSON;
+    buffer_strcat(wb, s);
+    buffer_no_cacheable(wb);
+
+    freez(s);
+
+    return HTTP_RESP_OK;
+}
+
+int web_client_api_request_v1_anomaly_event_info(RRDHOST *host, struct web_client *w, char *url) {
+    if (!netdata_ready)
+        return HTTP_RESP_BACKEND_FETCH_FAILED;
+
+    uint32_t after = 0, before = 0;
+
+    while (url) {
+        char *value = mystrsep(&url, "&");
+        if (!value || !*value)
+            continue;
+
+        char *name = mystrsep(&value, "=");
+        if (!name || !*name)
+            continue;
+        if (!value || !*value)
+            continue;
+
+        if (!strcmp(name, "after"))
+            after = (uint32_t) strtoul(value, NULL, 0);
+        else if (!strcmp(name, "before"))
+            before = (uint32_t) strtoul(value, NULL, 0);
+    }
+
+    char *s;
+    if (!before || !after)
+        s = strdupz("{\"error\": \"missing after/before parameters\" }\n");
+    else {
+        s = ml_get_anomaly_event_info(host, "AD1", 1, after, before);
+        if (!s)
+            s = strdupz("{\"error\": \"json string is empty\" }\n");
+    }
+
+    BUFFER *wb = w->response.data;
+    buffer_flush(wb);
+    wb->contenttype = CT_APPLICATION_JSON;
+    buffer_strcat(wb, s);
+    buffer_no_cacheable(wb);
+
+    freez(s);
+    return HTTP_RESP_OK;
+}
+
+int web_client_api_request_v1_ml_info(RRDHOST *host, struct web_client *w, char *url) {
+    (void) url;
+
+    if (!netdata_ready)
+        return HTTP_RESP_BACKEND_FETCH_FAILED;
+
+    char *s = ml_get_host_runtime_info(host);
+    if (!s)
+        s = strdupz("{\"error\": \"json string is empty\" }\n");
+
+    BUFFER *wb = w->response.data;
+    buffer_flush(wb);
+    wb->contenttype = CT_APPLICATION_JSON;
+    buffer_strcat(wb, s);
+    buffer_no_cacheable(wb);
+
+    freez(s);
+    return HTTP_RESP_OK;
+}
+
+#endif // defined(ENABLE_ML)
+
 inline int web_client_api_request_v1_info(RRDHOST *host, struct web_client *w, char *url) {
     (void)url;
     if (!netdata_ready) return HTTP_RESP_BACKEND_FETCH_FAILED;
@@ -995,6 +1234,23 @@ inline int web_client_api_request_v1_info(RRDHOST *host, struct web_client *w, c
     return HTTP_RESP_OK;
 }
 
+static int web_client_api_request_v1_aclk_state(RRDHOST *host, struct web_client *w, char *url) {
+    UNUSED(url);
+    UNUSED(host);
+    if (!netdata_ready) return HTTP_RESP_BACKEND_FETCH_FAILED;
+
+    BUFFER *wb = w->response.data;
+    buffer_flush(wb);
+
+    char *str = aclk_state_json();
+    buffer_strcat(wb, str);
+    freez(str);
+
+    wb->contenttype = CT_APPLICATION_JSON;
+    buffer_no_cacheable(wb);
+    return HTTP_RESP_OK;
+}
+
 static struct api_command {
     const char *command;
     uint32_t hash;
@@ -1019,7 +1275,15 @@ static struct api_command {
         { "alarm_variables", 0, WEB_CLIENT_ACL_DASHBOARD, web_client_api_request_v1_alarm_variables },
         { "alarm_count",     0, WEB_CLIENT_ACL_DASHBOARD, web_client_api_request_v1_alarm_count     },
         { "allmetrics",      0, WEB_CLIENT_ACL_DASHBOARD, web_client_api_request_v1_allmetrics      },
+
+#if defined(ENABLE_ML)
+        { "anomaly_events",     0, WEB_CLIENT_ACL_DASHBOARD, web_client_api_request_v1_anomaly_events     },
+        { "anomaly_event_info", 0, WEB_CLIENT_ACL_DASHBOARD, web_client_api_request_v1_anomaly_event_info },
+        { "ml_info",            0, WEB_CLIENT_ACL_DASHBOARD, web_client_api_request_v1_ml_info            },
+#endif
+
         { "manage/health",   0, WEB_CLIENT_ACL_MGMT,      web_client_api_request_v1_mgmt_health     },
+        { "aclk",            0, WEB_CLIENT_ACL_DASHBOARD, web_client_api_request_v1_aclk_state      },
         // terminator
         { NULL,              0, WEB_CLIENT_ACL_NONE,      NULL                                      },
 };
